=== modified file 'NEWS'
--- NEWS	2006-07-21 05:46:43 +0000
+++ NEWS	2006-07-21 17:52:22 +0000
@@ -188,6 +188,9 @@
     * Restore terminal mode on C-c while reading sftp password.  (#48923, 
       Nicholas Allen, Martin Pool)
 
+    * Branch.base has changed to a URL, but ~/.bazaar/locations.conf should
+      use local paths, since it is user visible (John Arbash Meinel, #53653)
+
   INTERNALS:
 
     * Combine the ignore rules into a single regex rather than looping over

=== modified file 'bzrlib/config.py'
--- bzrlib/config.py	2006-07-07 20:29:48 +0000
+++ bzrlib/config.py	2006-07-21 17:52:22 +0000
@@ -70,7 +70,7 @@
 from StringIO import StringIO
 
 import bzrlib
-import bzrlib.errors as errors
+from bzrlib import errors, urlutils
 from bzrlib.osutils import pathjoin
 from bzrlib.trace import mutter, warning
 import bzrlib.util.configobj.configobj as configobj
@@ -367,6 +367,11 @@
                         ' to ~/.bazaar/locations.conf')
             name_generator = branches_config_filename
         super(LocationConfig, self).__init__(name_generator)
+        # local file locations are looked up by local path, rather than
+        # by file url. This is because the config file is a user
+        # file, and we would rather not expose the user to file urls.
+        if location.startswith('file://'):
+            location = urlutils.local_path_from_url(location)
         self.location = location
 
     def _get_section(self):
@@ -382,7 +387,15 @@
             del location_names[-1]
         matches=[]
         for section in sections:
-            section_names = section.split('/')
+            # location is a local path if possible, so we need
+            # to convert 'file://' urls to local paths if necessary.
+            # This also avoids having file:///path be a more exact
+            # match than '/path'.
+            if section.startswith('file://'):
+                section_path = urlutils.local_path_from_url(section)
+            else:
+                section_path = section
+            section_names = section_path.split('/')
             if section.endswith('/'):
                 del section_names[-1]
             names = zip(location_names, section_names)

=== modified file 'bzrlib/tests/test_config.py'
--- bzrlib/tests/test_config.py	2006-06-30 18:54:10 +0000
+++ bzrlib/tests/test_config.py	2006-07-21 17:52:22 +0000
@@ -23,10 +23,9 @@
 import sys
 
 #import bzrlib specific imports here
-import bzrlib.config as config
+from bzrlib import config, errors, osutils, urlutils
 from bzrlib.branch import Branch
 from bzrlib.bzrdir import BzrDir
-import bzrlib.errors as errors
 from bzrlib.tests import TestCase, TestCaseInTempDir, TestCaseWithTransport
 
 
@@ -354,6 +353,29 @@
         b.nick = 'foo'
         self.assertTrue(b.get_config().has_explicit_nickname())
 
+    def test_config_url(self):
+        """The Branch.get_config will use section that uses a local url"""
+        branch = self.make_branch('branch')
+        self.assertEqual('branch', branch.nick)
+
+        locations = config.locations_config_filename()
+        config.ensure_config_dir_exists()
+        local_url = urlutils.local_path_to_url('branch')
+        open(locations, 'wb').write('[%s]\nnickname = foobar' 
+                                    % (local_url,))
+        self.assertEqual('foobar', branch.nick)
+
+    def test_config_local_path(self):
+        """The Branch.get_config will use a local system path"""
+        branch = self.make_branch('branch')
+        self.assertEqual('branch', branch.nick)
+
+        locations = config.locations_config_filename()
+        config.ensure_config_dir_exists()
+        open(locations, 'wb').write('[%s/branch]\nnickname = barry' 
+                                    % (osutils.getcwd().encode('utf8'),))
+        self.assertEqual('barry', branch.nick)
+
 
 class TestGlobalConfigItems(TestCase):
 

